@@ -8,16 +8,13 @@ import numpy as np
 import scipy.sparse as sp
 from nltk.probability import FreqDist
 
-from contextpro.exceptions import NotFitted
-from contextpro.normalization import batch_lowercase_text, batch_remove_stopwords
-from contextpro.processing import (
-    NestedTokenList,
-    SentenceList,
-    TokenList,
-    are_nested_string_lists,
-    is_string_list,
-    parallelize_func,
+from contextpro._exceptions import NotFitted
+from contextpro._processing import (
+    _is_nested_string_list,
+    _is_string_list,
+    _parallelize_func,
 )
+from contextpro.normalization import batch_lowercase_text, batch_remove_stopwords
 from contextpro.tokenization import batch_tokenize_text
 
 
@@ -30,14 +27,14 @@ class ConcurrentCountVectorizer:
     Parameters
     ----------
     lowercase : bool, optional
-        Convert all characters to lowercase before tokenizing
+        convert all characters to lowercase before tokenizing
 
     remove_stopwords : bool, optional
-        Remove stopwords. Uses english stopwords from the NLTK
+        remove stopwords. Uses english stopwords from the NLTK
         library, by default False
 
     ngram_range : Tuple[int, int], optional
-        The lower and upper boundary of the range of n-grams
+        the lower and upper boundary of the range of n-grams
         to be extracted and included in the vocabulary.
 
             - (1, 1) means only unigrams
@@ -47,11 +44,11 @@ class ConcurrentCountVectorizer:
             - (1, 3) means unigrams, bigrams and trigrams
 
     tokenizer_pattern : str, optional
-        RegEx pattern used by the underlying NLTK Regexp Tokenizer
+        regex pattern used by the underlying NLTK Regexp Tokenizer
         to tokenize the documents, by default r"\b[^\d\W]+\b"
 
     num_workers : Optional[int], optional
-        Number of processors to use, by default None (all processors)
+        number of processors to use, by default None (all processors)
 
     Examples
     --------
@@ -156,7 +153,7 @@ class ConcurrentCountVectorizer:
         Returns
         -------
         str
-            Regexp pattern used for tokenization
+            regexp pattern used for tokenization
         """
         return self._tokenizer_pattern
 
@@ -181,7 +178,7 @@ class ConcurrentCountVectorizer:
         Returns
         -------
         Optional[int]
-            Number of concurrent processes, by default None,
+            number of concurrent processes, by default None,
             which means use all available logical processor cores.
         """
         return self._num_workers
@@ -236,14 +233,14 @@ class ConcurrentCountVectorizer:
         self._ngram_range = value
 
     @property
-    def documents(self) -> Optional[SentenceList]:
+    def documents(self) -> Optional[List[str]]:
         """Documents used to train the vectorizer and build
         its vocabulary.
 
         Returns
         -------
-        Optional[SentenceList]
-            List of documents to learn the vocabulary from
+        Optional[List[str]]
+            list of documents to learn the vocabulary from
 
         Raises
         ------
@@ -257,19 +254,19 @@ class ConcurrentCountVectorizer:
             raise NotFitted("Vectorizer not fitted. Call 'fit()'method first")
 
     @documents.setter
-    def documents(self, value: SentenceList):
-        if is_string_list(value):
-            self._documents = SentenceList(value)
+    def documents(self, value: List[str]):
+        if _is_string_list(value):
+            self._documents = value
 
     @property
-    def tokens(self) -> Optional[NestedTokenList]:
+    def tokens(self) -> Optional[List[List[str]]]:
         """Nested token lists generated from the provided corpus of
         documents.
 
         Returns
         -------
-        Optional[NestedTokenList]
-            List of lists where each nested list represents a tokenized
+        Optional[List[List[str]]]
+            list of lists where each nested list represents a tokenized
             document.
 
         Raises
@@ -284,9 +281,9 @@ class ConcurrentCountVectorizer:
             raise NotFitted("Vectorizer not fitted. Call 'fit()'method first")
 
     @tokens.setter
-    def tokens(self, value: NestedTokenList):
-        if are_nested_string_lists(value):
-            self._tokens = NestedTokenList(value)
+    def tokens(self, value: List[List[str]]):
+        if _is_nested_string_list(value):
+            self._tokens = value
 
     @property
     def vocabulary(self) -> Optional[Dict[str, int]]:
@@ -295,7 +292,7 @@ class ConcurrentCountVectorizer:
         Returns
         -------
         Optional[Dict[str, int]]
-            Mapping from token(ngram) to its number in the vocabulary
+            mapping from token(ngram) to its number in the vocabulary
             dictionary
 
         Raises
@@ -318,33 +315,33 @@ class ConcurrentCountVectorizer:
             ):
                 self._vocabulary = value
 
-    def fit(self, documents: SentenceList):
+    def fit(self, documents: List[str]):
         """Preprocess the documents and learn vocabulary.
 
         Parameters
         ----------
-        documents : SentenceList
-            List of documents to learn the vocabulary from
+        documents : List[str]
+            list of documents to learn the vocabulary from
 
         Raises
         ------
         ValueError
             if not all elements of the 'documents' list are strings
         """
-        if not is_string_list(documents):
+        if not _is_string_list(documents):
             raise ValueError("'documents' should be a list of strings")
 
         self.documents = documents
         self.tokens = self._preprocess_documents(documents)
         self._build_vocabulary()
 
-    def transform(self, documents: SentenceList) -> sp.csr_matrix:
+    def transform(self, documents: List[str]) -> sp.csr_matrix:
         """Transform documents into a document-term matrix.
 
         Parameters
         ----------
-        documents : SentenceList
-            List of documents to transform
+        documents : List[str]
+            list of documents to transform
 
         Returns
         -------
@@ -356,7 +353,7 @@ class ConcurrentCountVectorizer:
         ValueError
             if not all elements of the 'documents' list are strings
         """
-        if not is_string_list(documents):
+        if not _is_string_list(documents):
             raise ValueError("'documents' should be a list of strings")
 
         docs = self._preprocess_documents(documents)
@@ -365,14 +362,14 @@ class ConcurrentCountVectorizer:
         docs_matrix = sp.csr_matrix(np.hstack(docs).T, dtype=np.uint32)
         return docs_matrix
 
-    def fit_transform(self, documents: SentenceList) -> sp.csr_matrix:
+    def fit_transform(self, documents: List[str]) -> sp.csr_matrix:
         """Learn the vocabulary dictionary from the provided document
         corpus and transform it into a document-term matrix.
 
         Parameters
         ----------
-        documents : SentenceList
-            List of documents to learn the vocabulary from and transform
+        documents : List[str]
+            list of documents to learn the vocabulary from and transform
 
         Returns
         -------
@@ -384,7 +381,7 @@ class ConcurrentCountVectorizer:
         ValueError
             if not all elements of the 'documents' list are strings
         """
-        if not is_string_list(documents):
+        if not _is_string_list(documents):
             raise ValueError("'documents' should be a list of strings")
 
         self.fit(documents)
@@ -485,117 +482,120 @@ class ConcurrentCountVectorizer:
             )
 
     @staticmethod
-    def get_ngrams(tokens: TokenList, n: int = 1) -> TokenList:
+    def get_ngrams(tokens: List[str], n: int = 1) -> List[str]:
         """Prepare n-grams from the provided list of tokens.
 
         Parameters
         ----------
-        tokens : TokenList
-            List of tokens representing single document
+        tokens : List[str]
+            list of tokens representing single document
         n : int, optional
-            Type of n-grams to produce, by default 1 (unigram)
+            type of n-grams to produce, by default 1 (unigram)
 
         Returns
         -------
-        TokenList
-            List of n-grams
+        List[str]
+            list of n-grams
 
         Raises
         ------
         ValueError
             if 'tokens' provided is not a list of strings
         """
-        if not is_string_list(tokens):
+        if not _is_string_list(tokens):
             raise ValueError("'tokens' should be a list of nested string lists")
 
         ngrams = []
         for num in range(0, len(tokens)):
             ngram = " ".join(tokens[num : num + n])
             ngrams.append(ngram)
-        return cast(
-            TokenList, [ngram for ngram in ngrams if len(ngram.split(" ")) == n]
-        )
+        return [ngram for ngram in ngrams if len(ngram.split(" ")) == n]
 
-    def get_unigrams(self, tokens: NestedTokenList) -> NestedTokenList:
+    def get_unigrams(self, tokens: List[List[str]]) -> List[List[str]]:
         """Prepare unigrams from the nested token lists.
 
         Parameters
         ----------
-        tokens : NestedTokenList
-            List of token lists, each representing single document
+        tokens : List[List[str]]
+            list of token lists, each representing single document
 
         Returns
         -------
-        NestedTokenList
-            List of lists of unigrams, each representing single document
+        List[List[str]]
+            list of lists of unigrams, each representing single document
 
         Raises
         ------
         ValueError
             if 'tokens' provided are not a list of nested string lists
         """
-        if not are_nested_string_lists(tokens):
+        if not _is_nested_string_list(tokens):
             raise ValueError("'tokens' should be a list of nested string lists")
 
-        unigrams = parallelize_func(
-            self.get_ngrams, tokens, n=1, num_workers=self.num_workers
+        return cast(
+            List[List[str]],
+            _parallelize_func(
+                self.get_ngrams, tokens, n=1, num_workers=self.num_workers
+            ),
         )
 
-        return cast(NestedTokenList, unigrams)
-
-    def get_bigrams(self, tokens: NestedTokenList) -> NestedTokenList:
+    def get_bigrams(self, tokens: List[List[str]]) -> List[List[str]]:
         """Prepare bigrams from the nested token lists.
 
         Parameters
         ----------
-        tokens : NestedTokenList
-            List of token lists, each representing single document
+        tokens : List[List[str]]
+            list of token lists, each representing single document
 
         Returns
         -------
-        NestedTokenList
-            List of lists of bigrams, each representing single document
+        List[List[str]]
+            list of lists of bigrams, each representing single document
 
         Raises
         ------
         ValueError
             if 'tokens' provided are not a list of nested string lists
         """
-        if not are_nested_string_lists(tokens):
+        if not _is_nested_string_list(tokens):
             raise ValueError("'tokens' should be a list of nested string lists")
 
-        bigrams = parallelize_func(
-            self.get_ngrams, tokens, n=2, num_workers=self.num_workers
+        return cast(
+            List[List[str]],
+            _parallelize_func(
+                self.get_ngrams, tokens, n=2, num_workers=self.num_workers
+            ),
         )
-        return cast(NestedTokenList, bigrams)
 
-    def get_trigrams(self, tokens: NestedTokenList) -> NestedTokenList:
+    def get_trigrams(self, tokens: List[List[str]]) -> List[List[str]]:
         """Prepare trigrams from the nested token lists.
 
         Parameters
         ----------
-        tokens : NestedTokenList
-            List of token lists, each representing single document
+        tokens : List[List[str]]
+            list of token lists, each representing single document
 
         Returns
         -------
-        NestedTokenList
-            List of lists of trigrams, each representing single document
+        List[List[str]]
+            list of lists of trigrams, each representing single document
 
         Raises
         ------
         ValueError
             if 'tokens' provided are not a list of nested string lists
         """
-        if not are_nested_string_lists(tokens):
+        if not _is_nested_string_list(tokens):
             raise ValueError("'tokens' should be a list of nested string lists")
 
-        trigrams = parallelize_func(
-            self.get_ngrams, tokens, n=3, num_workers=self.num_workers
+        return cast(
+            List[List[str]],
+            _parallelize_func(
+                self.get_ngrams, tokens, n=3, num_workers=self.num_workers
+            ),
         )
-        return cast(NestedTokenList, trigrams)
 
-    def _preprocess_documents(self, documents: SentenceList) -> NestedTokenList:
+    def _preprocess_documents(self, documents: List[str]) -> List[List[str]]:
         """Apply preprocessing methods to the provided document corpus"""
         if self.lowercase:
             documents = batch_lowercase_text(documents, num_workers=self.num_workers)
@@ -611,7 +611,7 @@ class ConcurrentCountVectorizer:
 
         return tokens
 
-    def _count_grams(self, ngrams: NestedTokenList) -> Dict[str, int]:
+    def _count_grams(self, ngrams: List[List[str]]) -> Dict[str, int]:
         """Count number of unique n-grams"""
         flat_grams = [ngram for doc in ngrams for ngram in doc]
         dist = FreqDist(flat_grams)
@@ -623,20 +623,22 @@ class ConcurrentCountVectorizer:
         flat_ngrams = sorted(set([ngram for doc in ngrams for ngram in doc]))
         self.vocabulary = {ngram: idx for idx, ngram in enumerate(flat_ngrams)}
 
-    def _docs_to_ngrams(self, tokens: NestedTokenList) -> NestedTokenList:
+    def _docs_to_ngrams(self, tokens: List[List[str]]) -> List[List[str]]:
         """Represent tokenized documents as n-gram lists."""
         return cast(
-            NestedTokenList,
-            parallelize_func(self._doc_to_ngrams, tokens, num_workers=self.num_workers),
+            List[List[str]],
+            _parallelize_func(
+                self._doc_to_ngrams, tokens, num_workers=self.num_workers
+            ),
         )
 
-    def _docs_to_matrix(self, tokens: NestedTokenList):
+    def _docs_to_matrix(self, tokens: List[List[str]]):
         """Represent tokenized documents as document-term matrix."""
-        return parallelize_func(
+        return _parallelize_func(
             self._doc_to_matrix, tokens, num_workers=self.num_workers
         )
 
-    def _doc_to_ngrams(self, tokens: TokenList) -> TokenList:
+    def _doc_to_ngrams(self, tokens: List[str]) -> List[str]:
         """Represent tokenized document as n-gram list."""
         ngram_range = range(self.ngram_range[0], self.ngram_range[1] + 1)
         ngrams = [self.get_ngrams(tokens, n) for n in ngram_range]
@@ -646,9 +648,9 @@ class ConcurrentCountVectorizer:
             for ngram in joined_ngrams
             if ngram != ""
         ]
-        return cast(TokenList, doc)
+        return doc
 
-    def _doc_to_matrix(self, tokens: TokenList):
+    def _doc_to_matrix(self, tokens: List[str]):
         """Represent tokenized document as a vector of n-gram counts."""
         if not self.vocabulary:
             raise NotFitted("Vectorizer not fitted. Call 'fit()'method first")
