@@ -16,37 +16,336 @@ from nltk.stem import (
 )
 from word2number import w2n
 
-from contextpro.processing import (
-    NestedTokenList,
-    Sentence,
-    SentenceList,
-    TokenList,
-    are_nested_string_lists,
-    is_string_list,
-    parallelize_func,
+from contextpro._processing import (
+    _is_nested_string_list,
+    _is_string_list,
+    _parallelize_func,
 )
 
 nlp = spacy.load("en_core_web_sm")
 
 
+def remove_stopwords(tokens: List[str], custom_stopwords: List[str] = []) -> List[str]:
+    """Removes stopwords from the provided list of tokens.
+
+    Parameters
+    ----------
+    tokens : List[str]
+        list of tokens, including stopwords
+    custom_stopwords : List[str], optional
+        which should be removed from the list of tokens, by default []
+
+    Returns
+    -------
+    List[str]
+        list of tokens without stopwords
+
+    Examples
+    --------
+    >>> from contextpro.normalization import remove_stopwords
+    >>> tokens = ['My', 'name', 'is', 'Dr', 'Jekyll']
+    >>> result = remove_stopwords(tokens)
+    >>> print(result)
+    ['My', 'name', 'Dr', 'Jekyll']
+    """
+
+    if custom_stopwords:
+        stop_words = set(custom_stopwords)
+    else:
+        stop_words = set(stopwords.words("english"))
+    return [word for word in tokens if word not in stop_words]
+
+
+def remove_non_ascii_characters(sentence: str) -> str:
+    """Removes non-ascii characters from the provided sentence.
+
+    Parameters
+    ----------
+    sentence : str
+        with non-ascii characters
+
+    Returns
+    -------
+    str
+        without non-ascii characters
+
+    Examples
+    --------
+    >>> from contextpro.normalization import remove_non_ascii_characters
+    >>> sentence = "https://sitebulb.com/Folder/øê.html?大学"
+    >>> result = remove_non_ascii_characters(sentence)
+    >>> print(result)
+    'https://sitebulb.com/Folder/.html?'
+    """
+    printable_chars = set(string.printable)
+    return "".join(filter(lambda char: char in printable_chars, sentence))
+
+
+def remove_punctuation(sentence: str) -> str:
+    """Removes punctuation characters from the sentence.
+
+    Parameters
+    ----------
+    sentence : str
+        with punctuation characters
+
+    Returns
+    -------
+    str
+        without punctuation characters
+
+    Examples
+    --------
+    >>> from contextpro.normalization import remove_punctuation
+    >>> corpus = "My name is Dr. Jekyll."
+    >>> result = remove_punctuation(sentence)
+    >>> print(result)
+    'My name is Dr Jekyll'
+    """
+    punctuation_chars = set(string.punctuation)
+    return "".join(filter(lambda char: char not in punctuation_chars, sentence))
+
+
+def remove_numbers(sentence: str) -> str:
+    """Removes numbers from the sentence.
+
+    Parameters
+    ----------
+    sentence : str
+        with number characters
+
+    Returns
+    -------
+    str
+        without number characters
+
+    Examples
+    --------
+    >>> from contextpro.normalization import remove_numbers
+    >>> sentence = "He is 12 years old."
+    >>> result = remove_numbers(sentence)
+    >>> print(result)
+    'He is  years old.'
+    """
+    digit_chars = set(string.digits)
+    return "".join(filter(lambda char: char not in digit_chars, sentence))
+
+
+def remove_whitespace(sentence: str) -> str:
+    """Removes whitespace characters from the sentence.
+
+    Parameters
+    ----------
+    sentence : str
+        with whitespace characters
+
+    Returns
+    -------
+    str
+        without whitespace characters
+
+    Examples
+    --------
+    >>> from contextpro.normalization import remove_whitespace
+    >>> sentence = "He Has Not Been    in Touch for over a Month."
+    >>> result = remove_whitespace(sentence)
+    >>> print(result)
+    'He Has Not Been in Touch for over a Month.'
+    """
+    return " ".join(re.split(r"\s+", sentence, flags=re.UNICODE))
+
+
+def convert_numerals_to_numbers(sentence: str) -> str:
+    """Replaces numerals with numbers in a sentence.
+
+    Parameters
+    ----------
+    sentence : str
+        with numerals
+
+    Returns
+    -------
+    str
+        with numerals replaced with numbers
+
+    Examples
+    --------
+    >>> from contextpro.normalization import convert_numerals_to_numbers
+    >>> sentence = "A bunch of five"
+    >>> result = convert_numerals_to_numbers(sentence)
+    >>> print(result)
+    'A bunch of 5'
+    """
+    spacy_doc = nlp(sentence)
+    try:
+        tokens = [
+            w2n.word_to_num(token.text) if token.pos_ == "NUM" else token.text
+            for token in spacy_doc
+        ]
+    except ValueError:
+        return sentence
+    return " ".join([str(token) for token in tokens])
+
+
+def replace_contractions(sentence: str, **kwargs) -> str:
+    """Expands contractions in a sentence.
+
+    Parameters
+    ----------
+    sentence : str
+        with contracted words
+
+    Returns
+    -------
+    str
+        without contracted words
+
+    Examples
+    --------
+    >>> from contextpro.normalization import replace_contractions
+    >>> sentence = "I don't want to be rude, but you shouldn't do this"
+    >>> result = replace_contractions(sentence)
+    >>> print(result)
+    'I do not want to be rude, but you should not do this'
+    """
+    return cast(str, contractions.fix(sentence, **kwargs))
+
+
+def lowercase_text(sentence: str) -> str:
+    """Converts sentence into lowercase.
+
+    Parameters
+    ----------
+    sentence : str
+        with characters of arbitrary size
+
+    Returns
+    -------
+    str
+        sentence with lowercased characters
+
+    Examples
+    --------
+    >>> from contextpro.normalization import lowercase_text
+    >>> sentence = "My name is Dr. Jekyll."
+
+    >>> result = lowercase_text(sentence)
+    >>> print(result)
+    'my name is dr. jekyll.'
+    """
+    return sentence.lower()
+
+
+def stem(
+    tokens: List[str], stemmer_type: Optional[str] = "nltk_porter_stemmer", **kwargs
+) -> List[str]:
+    """Reduces tokens to their root (base) form.
+
+    Parameters
+    ----------
+    tokens : List[str]
+        list of tokens containing words with various inflectional forms
+
+    stemmer_type : Optional[str], optional
+        stemmer type which will be used to stem the tokens,
+        by default "nltk_porter_stemmer"
+
+        Allowed values:
+          - nltk_porter_stemmer
+          - nltk_lancaster_stemmer
+          - nltk_regexp_stemmer
+          - nltk_snowball_stemmer
+
+    Other Parameters
+    ----------------
+    **kwargs : additional properties of the below stemmers:
+
+      - nltk.PorterStemmer
+      - nltk.LancasterStemmer
+      - nltk.RegexpStemmer
+      - nltk.SnowballStemmer
+
+    Returns
+    -------
+    List[str]
+        list of stemmed tokens
+
+    Examples
+    --------
+    >>> from contextpro.normalization import stem
+    >>> tokens =  ["I", "like", "driving", "a", "car"]
+    >>> result = stem(tokens, stemmer_type="nltk_porter_stemmer")
+    >>> print(result)
+    ['I', 'like', 'drive', 'a', 'car']
+    """
+
+    if stemmer_type == "nltk_porter_stemmer":
+        stemmer = PorterStemmer(**kwargs)
+    elif stemmer_type == "nltk_lancaster_stemmer":
+        stemmer = LancasterStemmer(**kwargs)
+    elif stemmer_type == "nltk_regexp_stemmer":
+        stemmer = RegexpStemmer(**kwargs)
+    else:
+        stemmer = SnowballStemmer(**kwargs)
+
+    return [stemmer.stem(word) for word in tokens]
+
+
+def lemmatize(
+    tokens: List[str],
+    **kwargs,
+) -> List[str]:
+    """Lemmatize tokens using NLTK's WordNetLemmatizer
+
+    Parameters
+    ----------
+    tokens : List[str]
+        list of tokens containing words with various inflectional forms
+
+    num_workers : Optional[int], optional
+        number of processors to use, by default None (all processors)
+
+    Other Parameters
+    ----------------
+    **kwargs : additional properties of the below lemmatizer:
+
+      - nltk.WordNetLemmatizer
+
+    Returns
+    -------
+    List[str]
+        list of lemmatized tokens
+
+    Examples
+    --------
+    >>> from contextpro.normalization import lemmatize
+    >>> tokens =  ["I", "like", "driving", "a", "car"]
+    >>> result = lemmatize(tokens, pos="v")
+    >>> print(result)
+    ['I', 'like', 'drive', 'a', 'car']
+    """
+    lemmatizer = WordNetLemmatizer()
+    return [lemmatizer.lemmatize(word, **kwargs) for word in tokens]
+
+
 def batch_lowercase_text(
-    documents: SentenceList,
+    documents: List[str],
     num_workers: Optional[int] = None,
-) -> SentenceList:
+) -> List[str]:
     """Converts sentences into lowercase in a concurrent manner.
 
     Parameters
     ----------
-    documents : SentenceList
-        List of sentences with characters of arbitrary size
+    documents : List[str]
+        list of sentences with characters of arbitrary size
 
     num_workers : Optional[int], optional
-        Number of processors to use, by default None (all processors)
+        number of processors to use, by default None (all processors)
 
     Returns
     -------
-    SentenceList
-        List of sentences with lowercased characters
+    List[str]
+        list of sentences with lowercased characters
 
     Raises
     ------
@@ -74,33 +373,33 @@ def batch_lowercase_text(
         "and this is tom parker"
     ]
     """
-    if not is_string_list(documents):
+    if not _is_string_list(documents):
         raise ValueError("'documents' should be a list of strings")
 
     return cast(
-        SentenceList,
-        parallelize_func(_lowercase_text, documents, num_workers=num_workers),
+        List[str],
+        _parallelize_func(lowercase_text, documents, num_workers=num_workers),
     )
 
 
 def batch_remove_non_ascii_characters(
-    documents: SentenceList,
+    documents: List[str],
     num_workers: Optional[int] = None,
-) -> SentenceList:
+) -> List[str]:
     """Removes non-ascii characters from sentences in a concurrent manner.
 
     Parameters
     ----------
-    documents : SentenceList
-        List of sentences with non-ascii characters
+    documents : List[str]
+        list of sentences with non-ascii characters
 
     num_workers : Optional[int], optional
-        Number of processors to use, by default None (all processors)
+        number of processors to use, by default None (all processors)
 
     Returns
     -------
-    SentenceList
-        List of sentences with removed non-ascii characters
+    List[str]
+        list of sentences with removed non-ascii characters
 
     Raises
     ------
@@ -128,39 +427,39 @@ def batch_remove_non_ascii_characters(
         'fractions , , '
     ]
     """
-    if not is_string_list(documents):
+    if not _is_string_list(documents):
         raise ValueError("'documents' should be a list of strings")
 
     return cast(
-        SentenceList,
-        parallelize_func(
-            _remove_non_ascii_characters, documents, num_workers=num_workers
+        List[str],
+        _parallelize_func(
+            remove_non_ascii_characters, documents, num_workers=num_workers
         ),
     )
 
 
 def batch_replace_contractions(
-    documents: SentenceList, num_workers: Optional[int] = None, **kwargs
-) -> SentenceList:
+    documents: List[str], num_workers: Optional[int] = None, **kwargs
+) -> List[str]:
     """Expands the contractions in sentences in a concurrent manner.
 
     Parameters
     ----------
-    documents : SentenceList
-        List of sentences with contracted words
+    documents : List[str]
+        list of sentences with contracted words
 
     num_workers : Optional[int]
-        Number of processors to use, by default None (all processors)
+        number of processors to use, by default None (all processors)
 
     Other Parameters
     ----------------
-    **kwargs : Additional properties of the below method:
+    **kwargs : additional properties of the below method:
       - contractions.fix()
 
     Returns
     -------
-    SentenceList
-        List of sentences without contractions
+    List[str]
+        list of sentences without contractions
 
     Raises
     ------
@@ -188,39 +487,39 @@ def batch_replace_contractions(
         'I am going for a walk',
     ]
     """
-    if not is_string_list(documents):
+    if not _is_string_list(documents):
         raise ValueError("'documents' should be a list of strings")
 
     return cast(
-        SentenceList,
-        parallelize_func(
-            _replace_contractions, documents, num_workers=num_workers, **kwargs
+        List[str],
+        _parallelize_func(
+            replace_contractions, documents, num_workers=num_workers, **kwargs
         ),
     )
 
 
 def batch_remove_stopwords(
-    tokens: NestedTokenList,
+    tokens: List[List[str]],
     custom_stopwords: List[str] = [],
     num_workers: Optional[int] = None,
-) -> NestedTokenList:
+) -> List[List[str]]:
     """Removes stopwords from lists of tokens in a concurrent manner.
 
     Parameters
     ----------
-    tokens : NestedTokenList
-        List of lists of tokens with stopwords
+    tokens : List[List[str]]
+        list of lists of tokens with stopwords
 
     custom_stopwords: List[str], optional
-        List of stopwords to remove from sentences, by default []
+        list of stopwords to remove from sentences, by default []
 
     num_workers : Optional[int], optional
-        Number of processors to use, by default None (all processors)
+        number of processors to use, by default None (all processors)
 
     Returns
     -------
-    NestedTokenList
-        List of lists of tokens without stopwords
+    List[List[str]]
+        list of lists of tokens without stopwords
 
     Raises
     ------
@@ -248,13 +547,13 @@ def batch_remove_stopwords(
         ['And', 'Tom', 'Parker']
     ]
     """
-    if not are_nested_string_lists(tokens):
+    if not _is_nested_string_list(tokens):
         raise ValueError("'tokens' should be a list of nested string lists")
 
     return cast(
-        NestedTokenList,
-        parallelize_func(
-            _remove_stopwords,
+        List[List[str]],
+        _parallelize_func(
+            remove_stopwords,
             tokens,
             custom_stopwords=custom_stopwords,
             num_workers=num_workers,
@@ -263,22 +562,22 @@ def batch_remove_stopwords(
 
 
 def batch_stem(
-    tokens: NestedTokenList,
+    tokens: List[List[str]],
     stemmer_type: Optional[str] = "nltk_porter_stemmer",
     num_workers: Optional[int] = None,
     **kwargs,
-) -> NestedTokenList:
+) -> List[List[str]]:
     """Stems tokens in lists of tokens to their root (base) form in a
     concurrent manner.
 
     Parameters
     ----------
-    tokens : NestedTokenList
-        List of lists of tokens containing words with various
+    tokens : List[List[str]]
+        list of lists of tokens containing words with various
         inflectional forms
 
     stemmer_type : Optional[str], optional
-        Stemmer instance which will be used to stem the tokens,
+        stemmer type which will be used to stem the tokens,
         by default "nltk_porter_stemmer"
 
         Allowed values:
@@ -288,11 +587,11 @@ def batch_stem(
           - nltk_snowball_stemmer
 
     num_workers : Optional[int], optional
-        Number of processors to use, by default None (all processors)
+        number of processors to use, by default None (all processors)
 
     Other Parameters
     ----------------
-    **kwargs : Additional properties of the below stemmers:
+    **kwargs : additional properties of the below stemmers:
 
       - nltk.PorterStemmer
       - nltk.LancasterStemmer
@@ -301,8 +600,8 @@ def batch_stem(
 
     Returns
     -------
-    NestedTokenList
-        List of lists of stemmed tokens
+    List[List[str]]
+        list of lists of stemmed tokens
 
     Raises
     ------
@@ -331,13 +630,13 @@ def batch_stem(
         ['I', 'have', 'three', 'bike', 'in', 'two', 'garag']
     ]
     """
-    if not are_nested_string_lists(tokens):
+    if not _is_nested_string_list(tokens):
         raise ValueError("'tokens' should be a list of nested string lists")
 
     return cast(
-        NestedTokenList,
-        parallelize_func(
-            _stem,
+        List[List[str]],
+        _parallelize_func(
+            stem,
             tokens,
             stemmer_type=stemmer_type,
             num_workers=num_workers,
@@ -347,32 +646,32 @@ def batch_stem(
 
 
 def batch_lemmatize(
-    tokens: NestedTokenList,
+    tokens: List[List[str]],
     num_workers: Optional[int] = None,
     **kwargs,
-) -> NestedTokenList:
+) -> List[List[str]]:
     """Lemmatizes tokens in lists of tokens in a concurrent manner using
     NLTK WordNetLemmatizer.
 
     Parameters
     ----------
-    tokens : NestedTokenList
-        List of lists of tokens containing words with various
+    tokens : List[List[str]]
+        list of lists of tokens containing words with various
         inflectional forms
 
     num_workers : Optional[int], optional
-        Number of processors to use, by default None (all processors)
+        number of processors to use, by default None (all processors)
 
     Other Parameters
     ----------------
-    **kwargs : Additional properties of the below lemmatizer:
+    **kwargs : additional properties of the below lemmatizer:
 
       - nltk.WordNetLemmatizer
 
     Returns
     -------
-    NestedTokenList
-        List of lists of lemmatized tokens
+    List[List[str]]
+        list of lists of lemmatized tokens
 
     Raises
     ------
@@ -401,32 +700,32 @@ def batch_lemmatize(
         ['Where', 'be', 'you', 'come', 'from']
     ]
     """
-    if not are_nested_string_lists(tokens):
+    if not _is_nested_string_list(tokens):
         raise ValueError("'tokens' should be a list of nested string lists")
 
     return cast(
-        NestedTokenList,
-        parallelize_func(_lemmatize, tokens, num_workers=num_workers, **kwargs),
+        List[List[str]],
+        _parallelize_func(lemmatize, tokens, num_workers=num_workers, **kwargs),
     )
 
 
 def batch_remove_punctuation(
-    documents: SentenceList, num_workers: Optional[int] = None
-) -> SentenceList:
+    documents: List[str], num_workers: Optional[int] = None
+) -> List[str]:
     """Removes punctuation characters from all sentences in a concurrent manner.
 
     Parameters
     ----------
-    documents : SentenceList
-        List of sentences which contain punctuation characters
+    documents : List[str]
+        list of sentences which contain punctuation characters
 
     num_workers : Optional[int]
-        Number of processors to use, by default None (all processors)
+        number of processors to use, by default None (all processors)
 
     Returns
     -------
-    SentenceList
-        List of sentences without punctuation characters
+    List[str]
+        list of sentences without punctuation characters
 
     Raises
     ------
@@ -454,32 +753,32 @@ def batch_remove_punctuation(
         'This is TomParker'
     ]
     """
-    if not is_string_list(documents):
+    if not _is_string_list(documents):
         raise ValueError("'documents' should be a list of strings")
 
     return cast(
-        SentenceList,
-        parallelize_func(_remove_punctuation, documents, num_workers=num_workers),
+        List[str],
+        _parallelize_func(remove_punctuation, documents, num_workers=num_workers),
     )
 
 
 def batch_remove_numbers(
-    documents: SentenceList, num_workers: Optional[int] = None
-) -> SentenceList:
+    documents: List[str], num_workers: Optional[int] = None
+) -> List[str]:
     """Removes numbers from all sentences in a concurrent manner.
 
     Parameters
     ----------
-    documents : SentenceList
-        List of sentences which contain numbers
+    documents : List[str]
+        list of sentences which contain numbers
 
     num_workers : Optional[int]
-        Number of processors to use, by default None (all processors)
+        number of processors to use, by default None (all processors)
 
     Returns
     -------
-    SentenceList
-        List of sentences without numbers
+    List[str]
+        list of sentences without numbers
 
     Raises
     ------
@@ -507,32 +806,32 @@ def batch_remove_numbers(
         'He earns $ daily'
     ]
     """
-    if not is_string_list(documents):
+    if not _is_string_list(documents):
         raise ValueError("'documents' should be a list of strings")
 
     return cast(
-        SentenceList,
-        parallelize_func(_remove_numbers, documents, num_workers=num_workers),
+        List[str],
+        _parallelize_func(remove_numbers, documents, num_workers=num_workers),
     )
 
 
 def batch_remove_whitespace(
-    documents: SentenceList, num_workers: Optional[int] = None
-) -> SentenceList:
+    documents: List[str], num_workers: Optional[int] = None
+) -> List[str]:
     r"""Removes whitespace characters from all sentences in a concurrent manner.
 
     Parameters
     ----------
-    documents : SentenceList
-        List of sentences which contain whitespace characters
+    documents : List[str]
+        list of sentences which contain whitespace characters
 
     num_workers : Optional[int]
-        Number of processors to use, by default None (all processors)
+        number of processors to use, by default None (all processors)
 
     Returns
     -------
-    SentenceList
-        List of sentences without whitespace characters
+    List[str]
+        list of sentences without whitespace characters
 
     Raises
     ------
@@ -560,32 +859,32 @@ def batch_remove_whitespace(
         'It Is Freezing Outside!',
     ]
     """
-    if not is_string_list(documents):
+    if not _is_string_list(documents):
         raise ValueError("'documents' should be a list of strings")
 
     return cast(
-        SentenceList,
-        parallelize_func(_remove_whitespace, documents, num_workers=num_workers),
+        List[str],
+        _parallelize_func(remove_whitespace, documents, num_workers=num_workers),
     )
 
 
 def batch_convert_numerals_to_numbers(
-    documents: SentenceList, num_workers: Optional[int] = None
-) -> SentenceList:
+    documents: List[str], num_workers: Optional[int] = None
+) -> List[str]:
     """Replaces numerals with numbers in all sentences in a concurrent manner.
 
     Parameters
     ----------
-    documents : SentenceList
-        List of sentences which contain numerals
+    documents : List[str]
+        list of sentences which contain numerals
 
     num_workers : Optional[int]
-        Number of processors to use, by default None (all processors)
+        number of processors to use, by default None (all processors)
 
     Returns
     -------
-    SentenceList
-        List of sentences with numerals converted to numbers
+    List[str]
+        list of sentences with numerals converted to numbers
 
     Raises
     ------
@@ -617,106 +916,28 @@ def batch_convert_numerals_to_numbers(
         'Between 2 stools',
     ]
     """
-    if not is_string_list(documents):
+    if not _is_string_list(documents):
         raise ValueError("'documents' should be a list of strings")
 
     return cast(
-        SentenceList,
-        parallelize_func(
-            _convert_numerals_to_digits, documents, num_workers=num_workers
+        List[str],
+        _parallelize_func(
+            convert_numerals_to_numbers, documents, num_workers=num_workers
         ),
     )
 
 
-def _remove_stopwords(tokens: TokenList, custom_stopwords: List[str] = []) -> TokenList:
-    """Removes stopwords from the provided list of tokens."""
-
-    if custom_stopwords:
-        stop_words = set(custom_stopwords)
-    else:
-        stop_words = set(stopwords.words("english"))
-    return cast(TokenList, [word for word in tokens if word not in stop_words])
-
-
-def _remove_non_ascii_characters(document: Sentence) -> Sentence:
-    """Removes non-ascii characters from the provided sentence."""
-    printable_chars = set(string.printable)
-    return cast(
-        Sentence, "".join(filter(lambda char: char in printable_chars, document))
-    )
-
-
-def _remove_punctuation(document: Sentence) -> Sentence:
-    """Removes punctuation characters from the sentence."""
-    punctuation_chars = set(string.punctuation)
-    return cast(
-        Sentence, "".join(filter(lambda char: char not in punctuation_chars, document))
-    )
-
-
-def _remove_numbers(document: Sentence) -> Sentence:
-    """Removes numbers from the sentence."""
-    digit_chars = set(string.digits)
-    return cast(
-        Sentence, "".join(filter(lambda char: char not in digit_chars, document))
-    )
-
-
-def _remove_whitespace(document: Sentence) -> Sentence:
-    """Removes whitespace characters from the sentence."""
-    return cast(Sentence, " ".join(re.split(r"\s+", document, flags=re.UNICODE)))
-
-
-def _convert_numerals_to_digits(document: Sentence) -> Sentence:
-    """Replaces numerals with numbers in a sentence."""
-    spacy_doc = nlp(document)
-    tokens = [
-        w2n.word_to_num(token.text) if token.pos_ == "NUM" else token.text
-        for token in spacy_doc
-    ]
-
-    return cast(Sentence, " ".join([str(token) for token in tokens]))
-
-
-def _replace_contractions(document: Sentence, **kwargs) -> Sentence:
-    """Expands the contractions in a sentence."""
-    return cast(Sentence, contractions.fix(document, **kwargs))
-
-
-def _lowercase_text(document: Sentence) -> Sentence:
-    """Converts the sentence to lowercase."""
-    return cast(Sentence, document.lower())
-
-
-def _stem(
-    tokens: TokenList, stemmer_type: Optional[str] = "nltk_porter_stemmer", **kwargs
-) -> TokenList:
-    """Reduces tokens to their root (base) form."""
-
-    if stemmer_type == "nltk_porter_stemmer":  # pragma: no cover
-        stemmer = PorterStemmer(**kwargs)
-    elif stemmer_type == "nltk_lancaster_stemmer":  # pragma: no cover
-        stemmer = LancasterStemmer(**kwargs)
-    elif stemmer_type == "nltk_regexp_stemmer":  # pragma: no cover
-        stemmer = RegexpStemmer(**kwargs)
-    else:  # pragma: no cover
-        stemmer = SnowballStemmer(**kwargs)
-
-    return cast(TokenList, [stemmer.stem(word) for word in tokens])  # pragma: no cover
-
-
-def _lemmatize(
-    tokens: TokenList,
-    **kwargs,
-) -> TokenList:
-    """Lemmatize tokens using NLTK's WordNetLemmatizer"""
-    lemmatizer = WordNetLemmatizer()  # pragma: no cover
-    return cast(
-        TokenList, [lemmatizer.lemmatize(word, **kwargs) for word in tokens]
-    )  # pragma: no cover
-
-
-_all_ = [
+__all__ = [
+    "remove_stopwords",
+    "remove_non_ascii_characters",
+    "remove_punctuation",
+    "remove_numbers",
+    "remove_whitespace",
+    "convert_numerals_to_numbers",
+    "replace_contractions",
+    "lowercase_text",
+    "stem",
+    "lemmatize",
     "batch_lowercase_text",
     "batch_remove_non_ascii_characters",
     "batch_replace_contractions",
